Package: padma
Type: Package
Title: Individualized Multi-Omic Pathway Deviation Scores Using
        Multiple Factor Analysis
Version: 1.22.0
Authors@R: c(
  person(given="Andrea", 
         family="Rau", 
         email="andrea.rau@inrae.fr", 
         role=c("cre", "aut"), 
         comment = c(ORCID = "0000-0001-6469-488X")),
  person(given="Regina",
         family="Manansala",
         email="manansa2@uwm.edu",
         role="aut"),
  person(given="Florence",
         family="Jaffrézic",
         email="florence.jaffrezic@inrae.fr",
         role="ctb"),
  person(given="Denis",
         family="Laloë",
         email="denis.laloe@inrae.fr",
         role="aut"),
  person(given="Paul",
         family="Auer",
         email="pauer@uwm.edu",
         role="aut"))
Depends: R (>= 4.1.0), SummarizedExperiment, S4Vectors
Imports: FactoMineR, MultiAssayExperiment, methods, graphics, stats,
        utils
Suggests: testthat, BiocStyle, knitr, rmarkdown, KEGGREST, missMDA,
        ggplot2, ggrepel, car, cowplot, reshape2
Description: 
  Use multiple factor analysis to calculate individualized pathway-centric 
  scores of deviation with respect to the sampled population based on multi-omic 
  assays (e.g., RNA-seq, copy number alterations, methylation, etc). Graphical 
  and numerical outputs are provided to identify highly aberrant individuals 
  for a particular pathway of interest, as well as the gene and omics drivers of 
  aberrant multi-omic profiles.
License: GPL (>=3)
URL: https://github.com/andreamrau/padma
https: //github.com/andreamrau/padma/issues
biocViews: Software, StatisticalMethod, PrincipalComponent,
        GeneExpression, Pathways, RNASeq, BioCarta, MethylSeq
Encoding: UTF-8
LazyData: TRUE
RoxygenNote: 7.3.1
VignetteBuilder: knitr
git_url: https://git.bioconductor.org/packages/padma
git_branch: RELEASE_3_23
git_last_commit: 080ac3b
git_last_commit_date: 2026-04-28
Repository: Bioconductor 3.23
Date/Publication: 2026-04-28
NeedsCompilation: no
Packaged: 2026-04-28 23:03:53 UTC; biocbuild
Author: Andrea Rau [cre, aut] (ORCID: <https://orcid.org/0000-0001-6469-488X>),
  Regina Manansala [aut],
  Florence Jaffrézic [ctb],
  Denis Laloë [aut],
  Paul Auer [aut]
Maintainer: Andrea Rau <andrea.rau@inrae.fr>
Built: R 4.6.0; ; 2026-04-29 04:53:58 UTC; unix
