# Generated by roxygen2: do not edit by hand

export(MFA_results)
export(factorMap)
export(imputed_genes)
export(ngenes)
export(omicsContrib)
export(padma)
export(padmaRun)
export(pathway_gene_deviation)
export(pathway_name)
export(removed_genes)
exportClasses(padmaResults)
exportMethods(MFA_results)
exportMethods(imputed_genes)
exportMethods(ngenes)
exportMethods(padma)
exportMethods(pathway_gene_deviation)
exportMethods(pathway_name)
exportMethods(removed_genes)
exportMethods(show)
exportMethods(summary)
import(MultiAssayExperiment)
import(SummarizedExperiment)
importClassesFrom(S4Vectors,DataFrame)
importFrom(FactoMineR,MFA)
importFrom(S4Vectors,DataFrame)
importFrom(graphics,abline)
importFrom(graphics,barplot)
importFrom(graphics,layout)
importFrom(graphics,lines)
importFrom(graphics,mtext)
importFrom(graphics,par)
importFrom(graphics,points)
importFrom(graphics,text)
importFrom(methods,as)
importFrom(methods,is)
importFrom(methods,new)
importFrom(stats,na.omit)
importFrom(stats,quantile)
importFrom(stats,reshape)
importFrom(stats,var)
importFrom(stats,weighted.mean)
importFrom(utils,data)
importFrom(utils,tail)
